@@ -9,5 +9,7 @@ from RenRen_Shop.api.RenRen_api import RenRenApi
 
 
 class Infos(RenRenApi):
-    def infos(self):
-        self.session.get(self.URL.seckill_edit())
\ No newline at end of file
+    def infos(self, id):
+        rep = self.session.get(self.URL.seckill_infos(), params={'id': id}, **self.kwargs)
+        if rep.json()['error'] == 0:
+            return rep.json()['data']
\ No newline at end of file
