@@ -7,12 +7,15 @@
 """
 import json
 import random
+import time
 
 from RenRen_Shop.factory import Factory
 
 
 if __name__ == '__main__':
     with Factory() as client:
-        goods_ids = client.goods.filter_goods('real_sales', 2, '>')
-        client.logger.info(f'筛选出的数量总数为：{len(goods_ids)}')
-        print(goods_ids)
+        data = {
+            'status': 1,
+        }
+        goods_ids = client.goods.fetch_goodsIds_list(**data)
+        print(len(goods_ids))
